
Credits
=======

Development sponsored by
    Elkjøp Nordic AS

Design and development
    `Martijn Pieters`_ at Jarn_

Contributions
    Jens Klein

Icon
    This icon is provided by `icons8`_ as Creative Commons Attribution-NoDerivs 3.0 Unported.

.. _Martijn Pieters: mailto:mj@jarn.com
.. _Jarn: http://www.jarn.com/
.. _icons8: https://icons8.com/
